@@ -43,7 +43,8 @@
 #include "xsltutils.h"
 #include "imports.h"
 #include "documents.h"
-
+#include "security.h"
+#include "pattern.h"
 
 
 /************************************************************************
@@ -55,27 +56,29 @@
 /**
  * xsltParseStylesheetImport:
  * @style:  the XSLT stylesheet
- * @template:  the "strip-space" element
+ * @cur:  the import element
  *
- * parse an XSLT stylesheet strip-space element and record
- * elements needing stripping
+ * parse an XSLT stylesheet import element
+ *
+ * Returns 0 in case of success -1 in case of failure.
  */
 
-void
+int
 xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
+    int ret = -1;
     xmlDocPtr import = NULL;
     xmlChar *base = NULL;
     xmlChar *uriRef = NULL;
     xmlChar *URI = NULL;
     xsltStylesheetPtr res;
+    xsltSecurityPrefsPtr sec;
 
     if ((cur == NULL) || (style == NULL))
-	return;
+	return (ret);
 
     uriRef = xsltGetNsProp(cur, (const xmlChar *)"href", XSLT_NAMESPACE);
     if (uriRef == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:import : missing href attribute\n");
 	goto error;
     }
@@ -83,26 +86,46 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
     base = xmlNodeGetBase(style->doc, cur);
     URI = xmlBuildURI(uriRef, base);
     if (URI == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:import : invalid URI reference %s\n", uriRef);
 	goto error;
     }
+
+    /*
+     * Security framework check
+     */
+    sec = xsltGetDefaultSecurityPrefs();
+    if (sec != NULL) {
+	int secres;
+
+	secres = xsltCheckRead(sec, NULL, URI);
+	if (secres == 0) {
+	    xsltTransformError(NULL, NULL, NULL,
+		 "xsl:import: read rights for %s denied\n",
+			     URI);
+	    goto error;
+	}
+    }
+
     import = xmlParseFile((const char *)URI);
     if (import == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:import : unable to load %s\n", URI);
 	goto error;
     }
 
-    res = xsltParseStylesheetDoc(import);
+    res = xsltParseStylesheetImportedDoc(import);
     if (res != NULL) {
 	res->parent = style;
 	res->next = style->imports;
 	style->imports = res;
+	xmlHashScan(res->templatesHash, 
+	            (xmlHashScanner) xsltNormalizeCompSteps, style);
 	style->extrasNr += res->extrasNr;
-    }
+	ret = 0;
+    } else {
+	xmlFreeDoc(import);
+	}
 
 error:
     if (uriRef != NULL)
@@ -111,19 +134,23 @@ error:
 	xmlFree(base);
     if (URI != NULL)
 	xmlFree(URI);
+
+    return (ret);
 }
 
 /**
  * xsltParseStylesheetInclude:
  * @style:  the XSLT stylesheet
- * @template:  the "strip-space" element
+ * @cur:  the include node
  *
- * parse an XSLT stylesheet strip-space element and record
- * elements needing stripping
+ * parse an XSLT stylesheet include element
+ *
+ * Returns 0 in case of success -1 in case of failure
  */
 
-void
+int
 xsltParseStylesheetInclude(xsltStylesheetPtr style, xmlNodePtr cur) {
+    int ret = -1;
     xmlDocPtr oldDoc;
     xmlChar *base = NULL;
     xmlChar *uriRef = NULL;
@@ -131,12 +158,11 @@ xsltParseStylesheetInclude(xsltStylesheetPtr style, xmlNodePtr cur) {
     xsltDocumentPtr include;
 
     if ((cur == NULL) || (style == NULL))
-	return;
+	return (ret);
 
     uriRef = xsltGetNsProp(cur, (const xmlChar *)"href", XSLT_NAMESPACE);
     if (uriRef == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:include : missing href attribute\n");
 	goto error;
     }
@@ -144,24 +170,27 @@ xsltParseStylesheetInclude(xsltStylesheetPtr style, xmlNodePtr cur) {
     base = xmlNodeGetBase(style->doc, cur);
     URI = xmlBuildURI(uriRef, base);
     if (URI == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:include : invalid URI reference %s\n", uriRef);
 	goto error;
     }
 
     include = xsltLoadStyleDocument(style, URI);
     if (include == NULL) {
-	xsltPrintErrorContext(NULL, style, cur);
-	xsltGenericError(xsltGenericErrorContext,
+	xsltTransformError(NULL, style, cur,
 	    "xsl:include : unable to load %s\n", URI);
 	goto error;
     }
 
     oldDoc = style->doc;
     style->doc = include->doc;
-    xsltParseStylesheetProcess(style, include->doc);
+    ret = (int)xsltParseStylesheetProcess(style, include->doc);
     style->doc = oldDoc;
+    if (ret == 0) {
+		ret = -1;
+		goto error;
+	}
+    ret = 0;
 
 error:
     if (uriRef != NULL)
@@ -170,6 +199,8 @@ error:
 	xmlFree(base);
     if (URI != NULL)
 	xmlFree(URI);
+
+    return (ret);
 }
 
 /**
@@ -201,7 +232,7 @@ xsltNextImport(xsltStylesheetPtr cur) {
  * xsltNeedElemSpaceHandling:
  * @ctxt:  an XSLT transformation context
  *
- * Returns whether that stylesheet requires white-space stripping
+ * Checks whether that stylesheet requires white-space stripping
  *
  * Returns 1 if space should be stripped, 0 if not
  */
@@ -242,18 +273,22 @@ xsltFindElemSpaceHandling(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	return(0);
     style = ctxt->style;
     while (style != NULL) {
-	/* TODO: add namespaces support */
-	val = (const xmlChar *)
-	      xmlHashLookup(style->stripSpaces, node->name);
+	if (node->ns != NULL) {
+	    val = (const xmlChar *)
+	      xmlHashLookup2(style->stripSpaces, node->name, node->ns->href);
+	} else {
+	    val = (const xmlChar *)
+		  xmlHashLookup2(style->stripSpaces, node->name, NULL);
+	}
 	if (val != NULL) {
 	    if (xmlStrEqual(val, (xmlChar *) "strip"))
 		return(1);
 	    if (xmlStrEqual(val, (xmlChar *) "preserve"))
 		return(0);
 	} 
-	if (ctxt->style->stripAll == 1)
+	if (style->stripAll == 1)
 	    return(1);
-	if (ctxt->style->stripAll == -1)
+	if (style->stripAll == -1)
 	    return(0);
 
 	style = xsltNextImport(style);
